#!/bin/bash
# This script will deregister this node with an Open Attestation Service
#
# TODO: should do some basic input validation so no errors are produced 
# when entering hardware information into the DB on the OAT Server.
if [ $UID -ne 0 ]; then
    echo "This can only be executed as root.  Aborting."
    exit 1
fi

if [ $# -ne 1 ]; then 
    echo "Usage: $0 <oat_server_fqdn>"
    echo "Where <oat_server_fqdn> must be the hostname of the OAT server node,"
    exit 1
fi

# OAT Server FQDN
oat_svc_host=$1

# Our hostname (just to be sure) 
hostname=`hostname -f`

# Get some details of the system (hardware, OS, etc.) to enter into the OAT db
oem_manu=`dmidecode -s system-manufacturer`
oem_desc=`dmidecode -s system-product-name`

os=`cat /etc/redhat-release | awk -F"release" '{print $1}'`
os_ver=`cat /etc/redhat-release | awk -F"release" '{print $2}'`
os_desc=$os

vmm=`virsh version | grep -i hyper | awk '{print $3}'`
vmm_ver=`virsh version | grep -i hyper | awk '{print $4}'`-$hostname
vmm_desc=$vmm

bios=`dmidecode -s bios-vendor`
bios_ver=`dmidecode -s bios-version`
bios_desc=`dmidecode -s baseboard-product-name`

pcr_00=`cat \`find /sys -name pcrs\` | grep PCR-00 | cut -c 8-80 | perl -pe 's/ //g'`
pcr_18=`cat \`find /sys -name pcrs\` | grep PCR-18 | cut -c 8-80 | perl -pe 's/ //g'`

# set oat service SSL cert path
export OAT_CERTFILE=$HOME/.oat_cer

# get oat service SSL cert
oat_cert -h $oat_svc_host 

#count the number of reference MLE in the system
count=0
#use this flag to determine whether the host wanted to delete is reference with specific MLE
flag=false
str=`oat_view_mle -h $oat_svc_host "{\"mleName\":\"$bios\",\"mleVersion\":\"$bios_ver\",\"oemName\":\"$oem_manu\"}"`
str2="`echo $str | awk -F, '{print $1}' | awk -F: '{print $2}'`"
hosts=`oat_host -s -h $oat_svc_host "{}" | awk -F] '{print $1}' | awk -F[ '{print $2}'`
hosts_arr=`echo | awk -v "raw=$hosts" 'BEGIN{split(raw,rawArr,"}"); for(i in rawArr) print rawArr[i]}'`
hoststr="\"HostName\":\"$hostname\""
biosstr="\"BIOS_Name\":\"$bios\""
biosverstr="\"BIOS_Version\":\"$bios_ver\""
oemmanustr="\"BIOS_Oem\":\"$oem_manu\""
if [ "null" == "$str2" -o "$str" == "${str/\"Name\":\"$bios\",\"Version\":\"$bios_ver\"/}" ];then
  echo "<$bios> mle is not in oat_db .. "
else
  while IFS='{' read -ra HOST; do
       for i in "${HOST[@]}"; do
           if [[ ! -z $i ]]
           then
                  if test "${i#*$biosstr}" != "$i" && test "${i#*$biosverstr}" != "$i" && test "${i#*$oemmanustr}" != "$i"; then
                      if test "${i#*$hoststr}" != "$i";
                      then
                          flag=true
                      fi
                      count=`expr $count + 1`
                      echo "matched host found"
                  fi
           fi
       done
  done <<< "$hosts_arr"
fi

# Del HOST from the oat_db
str=`oat_host  -s -h $oat_svc_host "{$hostname}"`
str2="`echo $str | awk -F] '{print $1}' | awk -F[ '{print $2}'`"
if [ "" == "$str2" -o "$str" == "${str/\"HostName\":\"$hostname\"/}" ];then
   echo "<$hostname> is not in oat_db .. "
else
   oat_host -d -h $oat_svc_host "{"hostName":"$hostname"}"
fi

# Del BIOS managed launch environment (mle) from the oat_db
if [ "$count" -le 1 -a "$flag" == true ]; then
  oat_mle -d -h $oat_svc_host "{\"mleName\":\"$bios\",\"mleVersion\":\"$bios_ver\",\"oemName\":\"$oem_manu\"}";
  echo "delete the MLE"
else
  echo -n "MLE is referenced with more than one host or no MLE is referenced with the host,";
  echo "no BIOS combined MLE will be removed from the system";
fi

# Del VMM measured launch environment (mle) from the oat_db
str=`oat_view_mle -h $oat_svc_host "{\"mleName\":\"$vmm\",\"mleVersion\":\"$vmm_ver\",\"osName\":\"$os\",\"osVersion\":\"$os_ver\"}"`
str2="`echo $str | awk -F, '{print $1}' | awk -F: '{print $2}'`"
if [ "null" == "$str2" -o  "$str" == "${str/\"Name\":\"$vmm\",\"Version\":\"$vmm_ver\"/}" ];then
  echo "<$vmm> mle is not in oat_db .. "
else
  oat_mle -d -h $oat_svc_host "{\"mleName\":\"$vmm\",\"mleVersion\":\"$vmm_ver\",\"osName\":\"$os\",\"osVersion\":\"$os_ver\"}"
fi

# Del the operating sytem from the oat_db (RH-like systems only)
str="`oat_view_os -h $oat_svc_host`"
str2="`echo $str | awk -F\] '{print $1}' | awk -F\[ '{print $2}'`"
if [ "" == "$str2" -o  "$str" == "${str/\"Name\":\"$os\"/}" ];then
  echo "<$os> OS is not in oat_db .. "
else
  oat_os -d -h $oat_svc_host "{\"Name\":\"$os\",\"Version\":\"$os_ver\"}"
fi

# Del the system hardware manufacturer (OEM) from the oat_db
str="`oat_view_oem -h $oat_svc_host`"
str2="`echo $str | awk -F\] '{print $1}' | awk -F\[ '{print $2}'`"
if [ "" == "$str2" -o "$str" == "${str/\"Name\":\"$oem_manu\"/}" ];then
  echo "<$oem_manu> oem is not in oat_db .. "
else
  oat_oem -d -h $oat_svc_host "{\"Name\":\"$oem_manu\"}"
fi

echo -e  "\n"
